==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/FLEETCUSTOMERCOSTCODEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FLEETCUSTOMERCOSTCODEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FLEETCUSTOMERCOSTCODEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETCUSTOMERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FLEETCUSTOMERCOSTCODEID_Type", propOrder = {
    "fleetcustomerid",
    "costcodeid"
})
public class FLEETCUSTOMERCOSTCODEID_Type {

    @XmlElement(name = "FLEETCUSTOMERID", required = true)
    protected FLEETCUSTOMERID_Type fleetcustomerid;
    @XmlElement(name = "COSTCODEID", required = true)
    protected COSTCODEID_Type costcodeid;

    /**
     * Obtient la valeur de la propriété fleetcustomerid.
     * 
     * @return
     *     possible object is
     *     {@link FLEETCUSTOMERID_Type }
     *     
     */
    public FLEETCUSTOMERID_Type getFLEETCUSTOMERID() {
        return fleetcustomerid;
    }

    /**
     * Définit la valeur de la propriété fleetcustomerid.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETCUSTOMERID_Type }
     *     
     */
    public void setFLEETCUSTOMERID(FLEETCUSTOMERID_Type value) {
        this.fleetcustomerid = value;
    }

    /**
     * Obtient la valeur de la propriété costcodeid.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Définit la valeur de la propriété costcodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/FLEETCUSTOMERCOSTCODEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FLEETCUSTOMERCOSTCODEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FLEETCUSTOMERCOSTCODEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETCUSTOMERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTCODEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FLEETCUSTOMERCOSTCODEID_Type", propOrder = {
    "fleetcustomerid",
    "costcodeid"
})
public class FLEETCUSTOMERCOSTCODEID_Type {

    @XmlElement(name = "FLEETCUSTOMERID", required = true)
    protected FLEETCUSTOMERID_Type fleetcustomerid;
    @XmlElement(name = "COSTCODEID", required = true)
    protected COSTCODEID_Type costcodeid;

    /**
     * Gets the value of the fleetcustomerid property.
     * 
     * @return
     *     possible object is
     *     {@link FLEETCUSTOMERID_Type }
     *     
     */
    public FLEETCUSTOMERID_Type getFLEETCUSTOMERID() {
        return fleetcustomerid;
    }

    /**
     * Sets the value of the fleetcustomerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FLEETCUSTOMERID_Type }
     *     
     */
    public void setFLEETCUSTOMERID(FLEETCUSTOMERID_Type value) {
        this.fleetcustomerid = value;
    }

    /**
     * Gets the value of the costcodeid property.
     * 
     * @return
     *     possible object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public COSTCODEID_Type getCOSTCODEID() {
        return costcodeid;
    }

    /**
     * Sets the value of the costcodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link COSTCODEID_Type }
     *     
     */
    public void setCOSTCODEID(COSTCODEID_Type value) {
        this.costcodeid = value;
    }

}
